kde5 needen library and programs moved.

This commit is contained in:
Ertuğrul Erata
2015-07-28 10:10:58 +03:00
parent d7a324d292
commit 8539a93625
62 changed files with 2309 additions and 32 deletions
+29
View File
@@ -0,0 +1,29 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Licensed under the GNU General Public License, version 3.
# See the file http://www.gnu.org/licenses/gpl.txt
from pisi.actionsapi import shelltools
from pisi.actionsapi import cmaketools
from pisi.actionsapi import pisitools
from pisi.actionsapi import get
def setup():
shelltools.makedirs("build")
shelltools.cd("build")
cmaketools.configure(sourceDir="..")
def build():
cmaketools.make("-C build")
cmaketools.make("-C build doc")
def install():
pisitools.dodoc("README", "TODO", "LICENSE")
shelltools.cd("build")
cmaketools.rawInstall("DESTDIR=%s" % get.installDIR())
pisitools.dohtml("doc/html/*")
pisitools.remove("/usr/bin/lit2epub")
@@ -0,0 +1,82 @@
diff -up ebook-tools-0.2.1/src/libepub/CMakeLists.txt.libzip_pkgconfig ebook-tools-0.2.1/src/libepub/CMakeLists.txt
--- ebook-tools-0.2.1/src/libepub/CMakeLists.txt.libzip_pkgconfig 2012-07-10 14:32:58.356257360 -0500
+++ ebook-tools-0.2.1/src/libepub/CMakeLists.txt 2012-07-10 14:32:58.359257323 -0500
@@ -1,6 +1,6 @@
-include_directories (${EBOOK-TOOLS_SOURCE_DIR}/src/libepub ${LIBXML2_INCLUDE_DIR} ${LIBZIP_INCLUDE_DIR})
+include_directories (${EBOOK-TOOLS_SOURCE_DIR}/src/libepub ${LIBXML2_INCLUDE_DIR} ${LIBZIP_INCLUDE_DIRS})
add_library (epub SHARED epub.c ocf.c opf.c linklist.c list.c)
-target_link_libraries (epub ${LIBZIP_LIBRARY} ${LIBXML2_LIBRARIES})
+target_link_libraries (epub ${LIBZIP_LIBRARIES} ${LIBXML2_LIBRARIES})
set_target_properties (epub PROPERTIES VERSION 0.2.1 SOVERSION 0)
+73
View File
@@ -0,0 +1,73 @@
<?xml version="1.0" ?>
<!DOCTYPE PISI SYSTEM "http://www.pisilinux.org/projeler/pisi/pisi-spec.dtd">
<PISI>
<Source>
<Name>ebook-tools</Name>
<Homepage>http://sourceforge.net/projects/ebook-tools/</Homepage>
<Packager>
<Name>PisiLinux Community</Name>
<Email>admins@pisilinux.org</Email>
</Packager>
<License>MIT</License>
<IsA>library</IsA>
<IsA>app:console</IsA>
<Summary>A tool for accessing and converting various ebook file formats</Summary>
<Description>ebook-tools is a programming library for accessing and converting various ebook file formats. It also contains a console application.</Description>
<Archive sha1sum="1f10bef62c9125cf804366134e486a58308f07ff" type="targz">mirrors://sourceforge/project/ebook-tools/ebook-tools/0.2.2/ebook-tools-0.2.2.tar.gz</Archive>
<BuildDependencies>
<Dependency>libzip-devel</Dependency>
<Dependency>doxygen</Dependency>
</BuildDependencies>
<Patches>
<Patch level="1">ebook-tools-0.2.1-libzip_pkgconfig.patch</Patch>
</Patches>
</Source>
<Package>
<Name>ebook-tools</Name>
<RuntimeDependencies>
<Dependency>libzip</Dependency>
</RuntimeDependencies>
<Files>
<Path fileType="executable">/usr/bin</Path>
<Path fileType="doc">/usr/share/doc</Path>
<Path fileType="library">/usr/lib</Path>
</Files>
</Package>
<Package>
<Name>ebook-tools-devel</Name>
<Summary>Development files for ebook-tools</Summary>
<RuntimeDependencies>
<Dependency release="current">ebook-tools</Dependency>
</RuntimeDependencies>
<Files>
<Path fileType="header">/usr/include</Path>
</Files>
</Package>
<Package>
<Name>ebook-tools-docs</Name>
<Summary>Documentation for ebook-tools</Summary>
<Files>
<Path fileType="doc">/usr/share/doc/ebook-tools/html</Path>
</Files>
</Package>
<History>
<Update release="2">
<Date>2014-01-22</Date>
<Version>0.2.2</Version>
<Comment>Version bump.</Comment>
<Name>Stefan Gronewold(groni)</Name>
<Email>groni@pisilinux.org</Email>
</Update>
<Update release="1">
<Date>2010-10-13</Date>
<Version>0.1.1</Version>
<Comment>First release</Comment>
<Name>Pisi Linux Admins</Name>
<Email>admins@pisilinux.org</Email>
</Update>
</History>
</PISI>
+18
View File
@@ -0,0 +1,18 @@
<?xml version="1.0" ?>
<PISI>
<Source>
<Name>ebook-tools</Name>
<Summary xml:lang="tr">Çeşitli e-kitap dosya biçimlerine erişmek için bir araç</Summary>
<Description xml:lang="tr">ebook-tools, çeşitli e-kitap dosya biçimleri arasında dönüştürme yapmak, bu biçimlere erişmek için kullanılan bir programlama kitaplığıdır. Kitaplığın yanında ayrıca bir terminal aracı da içerir.</Description>
</Source>
<Package>
<Name>ebook-tools-devel</Name>
<Summary xml:lang="tr">ebook-tools için geliştirme dosyaları</Summary>
</Package>
<Package>
<Name>ebook-tools-docs</Name>
<Summary xml:lang="tr">ebook-tools kitaplığı için belgelendirme</Summary>
</Package>
</PISI>
diff -up ebook-tools-0.2.1/cmake/FindLibZip.cmake.libzip_pkgconfig ebook-tools-0.2.1/cmake/FindLibZip.cmake
--- ebook-tools-0.2.1/cmake/FindLibZip.cmake.libzip_pkgconfig 2008-04-06 12:16:33.000000000 -0500
+++ ebook-tools-0.2.1/cmake/FindLibZip.cmake 2012-07-10 14:48:32.540578446 -0500
@@ -2,35 +2,55 @@
# Once done this will define
#
# LIBZIP_FOUND - system has the zip library
# LIBZIP_INCLUDE_DIR - the zip include directory
# LIBZIP_LIBRARY - Link this to use the zip library
#
# Copyright (c) 2006, Pino Toscano, <toscano.pino@tiscali.it>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
-if (LIBZIP_LIBRARY AND LIBZIP_INCLUDE_DIR)
+if (LIBZIP_LIBRARIES AND LIBZIP_INCLUDE_DIRS)
# in cache already
set(LIBZIP_FOUND TRUE)
-else (LIBZIP_LIBRARY AND LIBZIP_INCLUDE_DIR)
+else (LIBZIP_LIBRARIES AND LIBZIP_INCLUDE_DIRS)
+
+ # use pkg-config to get the directories and then use these values
+ # in the FIND_PATH() and FIND_LIBRARY() calls
+ FIND_PACKAGE(PkgConfig QUIET)
+ PKG_CHECK_MODULES(PC_LIBZIP libzip)
find_path(LIBZIP_INCLUDE_DIR zip.h
+ HINTS
+ ${GNUWIN32_DIR}/include
+ ${PC_LIBZIP_INCLUDEDIR}
+ ${PC_LIBZIP_INCLUDE_DIRS}
+ PATH_SUFFIXES libzip
+ )
+
+ find_path(LIBZIP_LIB_INCLUDE_DIR zipconf.h
+ HINTS
${GNUWIN32_DIR}/include
+ ${PC_LIBZIP_INCLUDEDIR}
+ ${PC_LIBZIP_INCLUDE_DIRS}
+ PATH_SUFFIXES libzip
)
+ set(LIBZIP_INCLUDE_DIRS ${LIBZIP_INCLUDE_DIR} ${LIBZIP_LIB_INCLUDE_DIR})
- find_library(LIBZIP_LIBRARY NAMES zip
- PATHS
+ find_library(LIBZIP_LIBRARIES NAMES zip
+ HINTS
+ ${PC_LIBZIP_LIBDIR}
+ ${PC_LIBZIP_LIBRARY_DIRS}
${GNUWIN32_DIR}/lib
)
include(FindPackageHandleStandardArgs)
- FIND_PACKAGE_HANDLE_STANDARD_ARGS(LibZip DEFAULT_MSG LIBZIP_LIBRARY LIBZIP_INCLUDE_DIR)
+ FIND_PACKAGE_HANDLE_STANDARD_ARGS(LibZip DEFAULT_MSG LIBZIP_LIBRARIES LIBZIP_INCLUDE_DIRS)
# ensure that they are cached
- set(LIBZIP_INCLUDE_DIR ${LIBZIP_INCLUDE_DIR} CACHE INTERNAL "The libzip include path")
- set(LIBZIP_LIBRARY ${LIBZIP_LIBRARY} CACHE INTERNAL "The libraries needed to use libzip")
+ set(LIBZIP_INCLUDE_DIRS ${LIBZIP_INCLUDE_DIRS} CACHE INTERNAL "The libzip include paths")
+ set(LIBZIP_LIBRARIES ${LIBZIP_LIBRARIES} CACHE INTERNAL "The libraries needed to use libzip")
-endif (LIBZIP_LIBRARY AND LIBZIP_INCLUDE_DIR)
+endif (LIBZIP_LIBRARIES AND LIBZIP_INCLUDE_DIRS)
-mark_as_advanced(LIBZIP_INCLUDE_DIR LIBZIP_LIBRARY)
+mark_as_advanced(LIBZIP_INCLUDE_DIRS LIBZIP_LIBRARIES)
@@ -2,35 +2,55 @@
#
# LIBZIP_FOUND - system has the zip library
-# LIBZIP_INCLUDE_DIR - the zip include directory
-# LIBZIP_LIBRARY - Link this to use the zip library
+# LIBZIP_INCLUDE_DIRS - the zip include directories
+# LIBZIP_LIBRARIES - Link this to use the zip library
#
# Copyright (c) 2006, Pino Toscano, <toscano.pino@tiscali.it>